==> fedeproxy-0.0.2.tar.gz: fedeproxy-0.0.2/fedeproxy/architecture/dvcs/test_dvcs.py <==
import os

import pytest
import sh

from .git import Git
from .hg import Hg


def populate_repository(d):
    open(f"{d}/README.md", "w").write("# testrepo")
    open(f"{d}/info.txt", "w").write("# someinfo")


def git_repository(d):
    sh.git.init(d)
    populate_repository(d)
    sh.git("-C", d, "add", "README.md", "info.txt")
    sh.git("-C", d, "commit", "-m", "initial")
    sh.git("-C", d, "checkout", "-b", "otherbranch")


def hg_repository(d):
    sh.hg.init(d)
    open(f"{d}/.hgkeep", "w").write("# init")
    sh.hg("--cwd", d, "add", ".hgkeep")
    sh.hg("--cwd", d, "commit", "-m", "initial")

    sh.hg("--cwd", d, "branch", "master")
    populate_repository(d)
    sh.hg("--cwd", d, "add", "README.md", "info.txt")
    sh.hg("--cwd", d, "commit", "-m", "initial")

    sh.hg("--cwd", d, "branch", "otherbranch")


@pytest.fixture(
    params=[
        (Git, git_repository),
        (Hg, hg_repository),
    ],
    ids=[
        "Git",
        "Hg",
    ],
)
def dvcs(request, tmpdir):
    (DVCS, repository) = request.param
    directory = f"{tmpdir}/testrepository"
    origin = f"{tmpdir}/origin"
    repository(origin)
    return DVCS(dir=directory, url=origin)


def test_dvcs_properties(dvcs):
    assert dvcs.directory
    assert dvcs.url


def test_dvcs_clone_master(dvcs):
    assert dvcs.clone("master") is True
    assert os.path.exists(f"{dvcs.directory}/README.md")
    assert dvcs.clone("master") is False


def test_dvcs_clone_not_master(dvcs):
    assert dvcs.clone("other") is True
    assert not os.path.exists(f"{dvcs.directory}/README.md")
    assert dvcs.clone("other") is False


def test_dvcs_commit(dvcs, tmpdir):
    assert dvcs.clone("master") is True
    content = "C"
    open(f"{dvcs.directory}/README.md", "w").write(content)
    dvcs.commit("message", "README.md")
    dvcs.push("master")

    DVCS = type(dvcs)
    other_dvcs = DVCS(dir=f"{tmpdir}/other", url=dvcs.url)
    assert other_dvcs.clone("master") is True
    assert open(f"{other_dvcs.directory}/README.md").read() == content


def test_dvcs_push_pull(dvcs, tmpdir):
    assert dvcs.clone("master") is True

    DVCS = type(dvcs)
    other_dvcs = DVCS(dir=f"{tmpdir}/other", url=dvcs.url)
    assert other_dvcs.clone("master") is True
    content = "C"
    open(f"{other_dvcs.directory}/README.md", "w").write(content)
    other_dvcs.commit("message", "README.md")
    other_dvcs.push("master")

    dvcs.pull("master")
    assert open(f"{dvcs.directory}/README.md").read() == content

==> fedeproxy-0.0.3.tar.gz: fedeproxy-0.0.3/fedeproxy/architecture/dvcs/test_dvcs.py <==
import os

import pytest

from . import factory


@pytest.fixture
def dvcs(dvcs_factory, tmpdir):
    (DVCS, repository) = dvcs_factory
    directory = f"{tmpdir}/testrepository"
    origin = f"{tmpdir}/origin"
    repository(origin).prepare_for_test()
    return DVCS(dir=directory, url=origin)


def test_dvcs_properties(dvcs):
    assert dvcs.directory
    assert dvcs.url
    assert dvcs.clone("master") is True
    assert dvcs.hash


def test_dvcs_clone_master(dvcs):
    assert dvcs.clone("master") is True
    assert os.path.exists(f"{dvcs.directory}/README.md")
    assert dvcs.clone("master") is False


def test_dvcs_clone_not_master(dvcs):
    assert dvcs.clone("other") is True
    assert not os.path.exists(f"{dvcs.directory}/README.md")
    assert dvcs.clone("other") is False


def test_dvcs_commit(dvcs, tmpdir):
    assert dvcs.clone("master") is True
    content = "C"
    open(f"{dvcs.directory}/README.md", "w").write(content)
    dvcs.commit("message", "README.md")
    dvcs.push("master")

    DVCS = type(dvcs)
    other_dvcs = DVCS(dir=f"{tmpdir}/other", url=dvcs.url)
    assert other_dvcs.clone("master") is True
    assert open(f"{other_dvcs.directory}/README.md").read() == content


def test_dvcs_push_pull(dvcs, tmpdir):
    assert dvcs.clone("master") is True

    DVCS = type(dvcs)
    other_dvcs = DVCS(dir=f"{tmpdir}/other", url=dvcs.url)
    assert other_dvcs.clone("master") is True
    content = "C"
    open(f"{other_dvcs.directory}/README.md", "w").write(content)
    other_dvcs.commit("message", "README.md")
    other_dvcs.push("master")

    dvcs.pull("master")
    assert open(f"{dvcs.directory}/README.md").read() == content


def test_dvcs_factory(dvcs):
    DVCS = type(dvcs)
    assert dvcs.clone("master") is True
    other_dvcs = factory(dvcs.directory)
    assert type(other_dvcs) == DVCS
    assert other_dvcs.url == dvcs.url


def test_dvcs_fetch_reset(dvcs_factory, dvcs, tmpdir):
    (DVCS, repository) = dvcs_factory
    other_origin = f"{tmpdir}/other_origin"
    repository(other_origin).prepare_for_test()
    other_dvcs = DVCS(dir=f"{tmpdir}/other", url=other_origin)
    assert other_dvcs.clone("master") is True
    other_hash = other_dvcs.hash

    assert dvcs.clone("master") is True
    hash = dvcs.hash
    assert dvcs.fetch(other_origin, other_hash) is True
    assert dvcs.hash == hash
    assert dvcs.fetch(other_origin, other_hash) is False
    assert dvcs.hash == hash
    assert dvcs.reset("master", other_hash) is True
    assert dvcs.hash == other_hash
